@@ -2,7 +2,7 @@
 # See LICENSE for details.
 
 __author__ = "Thinh Vu @thinh-vu in GitHub"
-__version__ = "0.0.1"
+__version__ = "0.0.4"
 
 from .fullstory_api import (
     fs_export,
@@ -11,5 +11,5 @@ from .fullstory_api import (
     fs_segment_export,
     fs_schedule_segment_export,
     fs_operation_status,
-    fs_export_result,
+    fs_export_result
 )
\ No newline at end of file
